__project__ = "orac"
__version__ = "0.1.1"
__author__ = "Philip Orange"
__email__ = "git@philiporange.com"
__url__ = "https://github.com/philiporange/orac"
__description__ = "A lightweight, YAML-driven framework for OpenAI-compatible LLM APIs."
__license__ = "CC0-1.0"
